cmd

package
v0.0.18 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 1, 2025 License: BSD-3-Clause Imports: 24 Imported by: 0

Documentation

Overview

Package cmd implements the command-line interface for inboxfewer.

This package provides the following commands:

  • cleanup: Archive Gmail threads related to closed GitHub issues and pull requests
  • serve: Start the MCP server to provide tools for AI assistants
  • version: Display version information
  • generate-docs: Generate markdown documentation for all MCP tools

The cleanup command is the default command when no subcommand is specified.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute is the main entry point for the CLI application

func SetVersion

func SetVersion(v string)

SetVersion sets the version for the root command

Types

This section is empty.

Jump to